@@ -1,7 +1,7 @@
 package Melian;
 our $AUTHORITY = 'cpan:XSAWYERX';
 # ABSTRACT: Perl client to the Melian cache
-$Melian::VERSION = '0.005';
+$Melian::VERSION = '0.006';
 use v5.34;
 use Carp qw(croak);
 use IO::Socket::INET;
@@ -244,7 +244,7 @@ sub load_schema_from_file {
     return $decoded;
 }
 
-# table1#0|60|id:int,table2#1|45|id:int;hostname:string
+# table1#0|60|id#0:int,table2#1|45|id#0:int;hostname#1:string
 sub load_schema_from_spec {
     my $spec = shift;
     my %data;
@@ -415,7 +415,7 @@ Melian - Perl client to the Melian cache
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -584,7 +584,7 @@ This saves name lookups on every request.
     my $melian = Melian->new(
         'dsn'         => 'unix:///tmp/melian.sock',
         'timeout'     => 1, # Only relevant for TCP/IP
-        'schema_spec' => 'people#0|60|id:int',
+        'schema_spec' => 'people#0|60|id#0:int',
     );
 
 Creates a new client and automatically loads the schema.
